@@ -11,8 +11,8 @@ use swc_ecma_transforms_base::{
     helpers::{inject_helpers, HELPERS},
     hygiene::hygiene,
 };
-use swc_ecma_utils::{find_ids, private_ident, ExprFactory};
-use swc_ecma_visit::{noop_fold_type, noop_visit_type, Fold, FoldWith, Visit, VisitWith};
+use swc_ecma_utils::{contains_top_level_await, find_ids, private_ident, ExprFactory};
+use swc_ecma_visit::{noop_fold_type, Fold, FoldWith};
 
 use crate::{hash::calc_hash, Bundle, BundleKind, Bundler, Load, ModuleType, Resolve};
 
@@ -148,10 +148,7 @@ where
             return module;
         }
 
-        let mut top_level_await_finder = TopLevelAwaitFinder::default();
-        module.visit_with(&mut top_level_await_finder);
-
-        let is_async = top_level_await_finder.found;
+        let is_async = contains_top_level_await(&module);
 
         // Properties of returned object
         let mut props = vec![];
@@ -365,21 +362,6 @@ where
     }
 }
 
-#[derive(Default)]
-struct TopLevelAwaitFinder {
-    found: bool,
-}
-
-impl Visit for TopLevelAwaitFinder {
-    noop_visit_type!();
-
-    fn visit_stmts(&mut self, _: &[Stmt]) {}
-
-    fn visit_await_expr(&mut self, _: &AwaitExpr) {
-        self.found = true;
-    }
-}
-
 /// Import renamer. This pass changes import path.
 struct Renamer<'a, R>
 where
